%define         major   0.25
%define         libname %mklibname %{name} %{major}
%define         devel   %mklibname %{name} -d

Name:           tree-sitter
Version:        0.25.4
Release:        %mkrel 1
Summary:        An incremental parsing system for programming tools
Group:          System/Libraries
License:        MIT
URL:            https://tree-sitter.github.io/
Source0:        https://github.com/tree-sitter/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz
# Upstream change: soname will now include the minor version #3308
# so no need to symlink with major version (.so.0)
Patch0:         tree-sitter-fix-libs-soname.patch

BuildRequires: gcc
BuildRequires: make


%description
Tree-sitter is a parser generator tool and an incremental parsing
library. It can build a concrete syntax tree for a source file
and efficiently update the syntax tree as the source file is
edited. Tree-sitter aims to be:

 * General enough to parse any programming language
 * Fast enough to parse on every keystroke in a text editor
 * Robust enough to provide useful results even in the presence
   of syntax errors
 * Dependency-free so that the runtime library (which is written
   in pure C) can be embedded in any application

%package -n %{libname}
Summary:        Incremental parsing library for programming tools
Group:          System/Libraries

Obsoletes:      %{_lib}tree-sitter0 < 0.23.0-2

%description -n %{libname}
Tree-sitter is a parser generator tool and an incremental parsing
library. It can build a concrete syntax tree for a source file
and efficiently update the syntax tree as the source file is
edited. This is the package with the dynamically linked C library.

%package -n %{devel}
Summary:        Development files for %{name}
Requires:       %{libname} = %{version}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devel}
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%autosetup -p1

%build
%set_build_flags
export PREFIX='%{_prefix}' LIBDIR='%{_libdir}'
%make_build

%install
export PREFIX='%{_prefix}' LIBDIR='%{_libdir}' INCLUDEDIR='%{_includedir}'
%make_install

find %{buildroot}%{_libdir} -type f \( -name "*.la" -o -name "*.a" \) -delete -print

%files -n %{libname}
%license LICENSE
%doc README.md
%{_libdir}/libtree-sitter.so.%{major}{,.*}

%files -n %{devel}
%{_includedir}/tree_sitter/
%{_libdir}/libtree-sitter.so
%{_libdir}/pkgconfig/tree-sitter.pc



%changelog
* Sun May 11 2025 kekepower <kekepower> 0.25.4-1.mga10
+ Revision: 2182463
- Update to version 0.25.4

* Sun May 04 2025 kekepower <kekepower> 0.25.3-1.mga10
+ Revision: 2180849
- Update to version 0.25.3

* Mon Feb 24 2025 daviddavid <daviddavid> 0.25.2-1.mga10
+ Revision: 2151854
- new version: 0.25.2
- now libmajor is 0.25

* Thu Nov 14 2024 kekepower <kekepower> 0.24.4-1.mga10
+ Revision: 2115157
- Update to version 0.24.4

* Thu Oct 10 2024 kekepower <kekepower> 0.24.3-1.mga10
+ Revision: 2104587
- Update to version 0.24.3

* Sun Oct 06 2024 kekepower <kekepower> 0.24.2-1.mga10
+ Revision: 2103750
- Update to version 0.24.2

* Sat Oct 05 2024 kekepower <kekepower> 0.24.1-1.mga10
+ Revision: 2103404
- Update to version 0.24.1

* Thu Oct 03 2024 kekepower <kekepower> 0.23.2-1.mga10
+ Revision: 2102891
- Update to version 0.23.2

* Tue Oct 01 2024 kekepower <kekepower> 0.23.1-1.mga10
+ Revision: 2102195
- Update to version 0.23.1

* Wed Aug 28 2024 daviddavid <daviddavid> 0.23.0-2.mga10
+ Revision: 2092024
- fix library pkgname (The soname will now include the minor version #3308)

* Tue Aug 27 2024 kekepower <kekepower> 0.23.0-1.mga10
+ Revision: 2091626
- Update to version 0.23.0

* Mon May 06 2024 kekepower <kekepower> 0.22.6-1.mga10
+ Revision: 2062590
- Update to version 0.22.6

* Tue Apr 16 2024 kekepower <kekepower> 0.22.5-1.mga10
+ Revision: 2058067
- Update to version 0.22.5

* Sun Apr 14 2024 kekepower <kekepower> 0.22.4-1.mga10
+ Revision: 2057084
- Update to version 0.22.4

* Mon Mar 18 2024 kekepower <kekepower> 0.22.2-1.mga10
+ Revision: 2050380
- Update to version 0.22.2

* Tue Mar 12 2024 kekepower <kekepower> 0.22.1-1.mga10
+ Revision: 2049313
- Update to version 0.22.1

* Thu Feb 22 2024 kekepower <kekepower> 0.21.0-1.mga10
+ Revision: 2043090
- Update to version 0.21.0

* Fri Jan 26 2024 kekepower <kekepower> 0.20.9-1.mga10
+ Revision: 2035005
- Update to version 0.20.9

* Tue Apr 04 2023 kekepower <kekepower> 0.20.8-2.mga9
+ Revision: 1951413
- Update tarball to new release 0.20.8
  o There was an issue with the last release and it was pulled

* Tue Mar 14 2023 kekepower <kekepower> 0.20.8-1.mga9
+ Revision: 1948956
- Update to version 0.20.8

* Sat Sep 03 2022 kekepower <kekepower> 0.20.7-1.mga9
+ Revision: 1883593
- Update to version 0.20.7

* Fri Mar 18 2022 umeabot <umeabot> 0.20.6-2.mga9
+ Revision: 1797887
- Mageia 9 Mass Rebuild

* Thu Mar 03 2022 kekepower <kekepower> 0.20.6-1.mga9
+ Revision: 1788083
- Update to version 0.20.6

* Sat Jan 22 2022 kekepower <kekepower> 0.20.3-1.mga9
+ Revision: 1769433
- Update to version 0.20.3

* Sat Jan 01 2022 kekepower <kekepower> 0.20.2-1.mga9
+ Revision: 1765920
- Update to version 0.20.2

* Mon Nov 22 2021 kekepower <kekepower> 0.20.1-1.mga9
+ Revision: 1758677
- Update to version 0.20.1

* Mon Jul 05 2021 kekepower <kekepower> 0.20.0-1.mga9
+ Revision: 1734886
- imported package tree-sitter

